@@ -7,6 +7,7 @@
 module Control.Monad.Extra(
     module Control.Monad,
     whenJust, whenJustM,
+    pureIf,
     whenMaybe, whenMaybeM,
     unit,
     maybeM, fromMaybeM, eitherM,
@@ -29,6 +30,7 @@ import Prelude
 -- General utilities
 
 -- | Perform some operation on 'Just', given the field inside the 'Just'.
+--   This is a specialized 'Data.Foldable.for_'.
 --
 -- > whenJust Nothing  print == pure ()
 -- > whenJust (Just 1) print == print 1
@@ -40,6 +42,14 @@ whenJustM :: Monad m => m (Maybe a) -> (a -> m ()) -> m ()
 -- Can't reuse whenMaybe on GHC 7.8 or lower because Monad does not imply Applicative
 whenJustM mg f = maybeM (pure ()) f mg
 
+-- | Return either a `pure` value if a condition is `True`, otherwise `empty`.
+--
+-- > pureIf @Maybe True  5 == Just 5
+-- > pureIf @Maybe False 5 == Nothing
+-- > pureIf @[]    True  5 == [5]
+-- > pureIf @[]    False 5 == []
+pureIf :: (Alternative m) => Bool -> a -> m a
+pureIf b a = if b then pure a else empty
 
 -- | Like 'when', but return either 'Nothing' if the predicate was 'False',
 --   of 'Just' with the result of the computation.
@@ -56,7 +66,6 @@ whenMaybeM mb x = do
     b <- mb
     if b then liftM Just x else pure Nothing
 
-
 -- | The identity function which requires the inner argument to be @()@. Useful for functions
 --   with overloaded return types.
 --
